@@ -36,13 +36,13 @@ from ..exceptions import CloudifyCliError
 @cfy.command(name='init', short_help='Initialize a working env')
 @cfy.argument('blueprint-path', required=False)
 @cfy.options.blueprint_filename()
-@cfy.options.blueprint_id(required=False, multiple_blueprints=True)
+@cfy.options.blueprint_id(required=False, validate=True)
 @cfy.options.reset_context
 @cfy.options.inputs
 @cfy.options.install_plugins
 @cfy.options.init_hard_reset
 @cfy.options.enable_colors
-@cfy.options.verbose()
+@cfy.options.common_options
 @cfy.pass_logger
 def init(blueprint_path,
          blueprint_filename,
@@ -88,12 +88,10 @@ def init(blueprint_path,
             blueprint_filename
         )
 
-        if env.MULTIPLE_LOCAL_BLUEPRINTS:
-            blueprint_id = blueprint_id or blueprint.generate_id(
-                processed_blueprint_path,
-                blueprint_filename
-            )
-
+        blueprint_id = blueprint_id or blueprint.generate_id(
+            processed_blueprint_path,
+            blueprint_filename
+        )
         if os.path.isdir(local.storage_dir(blueprint_id)):
             shutil.rmtree(local.storage_dir(blueprint_id))
 
@@ -152,7 +150,7 @@ def init_manager_profile(profile_name,
                          logger=None):
     logger.info('Initializing profile {0}...'.format(profile_name))
 
-    context_file_path = env.get_context_path(profile_name, suppress_error=True)
+    context_file_path = env.get_context_path(profile_name)
 
     if context_file_path and os.path.isfile(context_file_path):
         if reset_context:
@@ -175,7 +173,7 @@ def init_manager_profile(profile_name,
 def _create_profiles_dir_and_config(hard, enable_colors):
     if not os.path.isdir(env.PROFILES_DIR):
         os.makedirs(env.PROFILES_DIR)
-    if not os.path.isfile(config.CLOUDIFY_CONFIG_PATH) or hard:
+    if not env.config_initialized_with_logging() or hard:
         set_config(enable_colors=enable_colors)
 
     configure_loggers()
@@ -193,7 +191,7 @@ def _raise_initialized_error(profile_name):
 def set_config(enable_colors=False):
     cli_config = pkg_resources.resource_string(
         cloudify_cli.__name__,
-        'config/config_template.yaml')
+        'config/config_template.yaml').decode('utf-8')
 
     enable_colors = str(enable_colors).lower()
     template = Template(cli_config)
@@ -201,6 +199,6 @@ def set_config(enable_colors=False):
         log_path=DEFAULT_LOG_FILE,
         enable_colors=enable_colors
     )
-    with open(config.CLOUDIFY_CONFIG_PATH, 'w') as f:
+    with open(config.CLOUDIFY_CONFIG_PATH, 'a') as f:
         f.write(rendered)
         f.write(os.linesep)
